# LIE

Este proyecto es realizado para la Fundación Omar Dengo, como la primera etapa de un sistema para la evaluación de pensamiento computacional en estudiantes de tercer a noveno año de colegio en El Ministerio de Educación Pública de Costa Rica. 

El objetivo principal del proyecto es desarrollar un lenguaje nuevo en español y un intérprete que tenga como salida la 
estructura de código utilizado por un estudiante determinado para resolver un problema de programación e inidcar si está salida. 

## Publicación 


### Desarrollado con 

* [Pycharm](https://www.jetbrains.com/es-es/pycharm/) - Codificación 
* [ANTLR v4](https://www.antlr.org/) - Gramática y Pruebas 

### Administración de versiones 

Se usa [Github](https://github.com/github) para manejo de versiones. 

### Autores 

* **Janis Cervantes Loría**
* **Michael Gonzalez Rivera**
* **Luis Saborio Hernandez**
* **Ellioth Ramirez Trejos**

### Licencia 
